@@ -10,7 +10,7 @@
 
 CFGFILE="/etc/runlevel.conf"
 BAKCFG="/etc/runlevel.fallback"
-LOCKFILE="/var/lock/runlevel.lock"
+LOCKFILE="/etc/runlevel.lock"
 TMPFILE="/etc/runlevel.tmp"
 
 i=0
@@ -41,7 +41,7 @@ done
 while read  SORT_NO  OFF_LEVELS  ON_LEVELS  CMD  OPTIONS
 do
     case "$SORT_NO" in
-	"#" | "#*" | "") continue ;;
+	\#*|""|\#) continue ;;
     esac
     [ ! -f $CMD ] && continue
 
